@@ -30,35 +30,97 @@ from ..synapses.utils import catmaid_table
 from ..synapses.transmitters import collapse_nt_predictions
 
 __all__ = ['fetch_synapses', 'fetch_connectivity', 'predict_transmitter',
-           'fetch_adjacency']
+           'fetch_adjacency', 'synapse_counts']
 
 
-def synapse_counts(x, batch_size=10, dataset='production'):
+def synapse_counts(x, by_neuropil=False, min_score=30, live_query=True,
+                   batch_size=10, dataset='production', **kwargs):
     """Fetch synapse counts for given root IDs.
 
     Parameters
     ----------
     x :             int | list of int | Neuron/List
-                    Either a flywire segment ID (i.e. root ID), a list thereof or
+                    Either a FlyWire segment ID (i.e. root ID), a list thereof or
                     a Neuron/List. For neurons, the ``.id`` is assumed to be the
                     root ID. If you have a neuron (in FlyWire space) but don't
                     know its ID, use :func:`fafbseg.flywire.neuron_to_segments`
                     first.
+    by_neuropil :   bool
+                    If True, returned DataFrame will contain a break down by
+                    neuropil.
+    min_score :     int, optional
+                    Minimum "cleft score". The default of 30 is what Buhmann et al.
+                    used in the paper.
+    live_query :    bool
+                    Whether to query against the live data or against the latest
+                    materialized table. The latter is useful if you are working
+                    with IDs that you got from another annotation table.
+    batch_size :    int
+                    Number of IDs to query per batch. Too large batches might
+                    lead to truncated tables: currently individual queries can
+                    not return more than 200_000 rows and you will see a warning
+                    if that limit is exceeded.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query::
+                    Against which FlyWire dataset to query::
                         - "production" (current production dataset, fly_v31)
                         - "sandbox" (i.e. fly_v26)
+    **kwargs
+                    Keyword arguments are passed through to
+                    :func:`fafbseg.flywire.fetch_synapses`.
 
     Returns
     -------
     pandas.DataFrame
+                    If ``by_neuropil=False`` returns counts indexed by root ID.
+                    If ``by_neuropil=True`` returns counts indexed by root ID
+                    and neuropil.
 
     """
-    pass
+    # Parse root IDs
+    ids = parse_root_ids(x)
+
+    # First get the synapses
+    syn = fetch_synapses(x, pre=True, post=True, attach=False,
+                         min_score=min_score,
+                         transmitters=True, live_query=live_query,
+                         neuropils=by_neuropil,
+                         dataset=dataset, **kwargs)
+
+    pre = syn[syn.pre.isin(x)]
+    post = syn[syn.post.isin(x)]
+
+    if not by_neuropil:
+        counts = pd.DataFrame()
+        counts['id'] = ids
+        counts['pre'] = pre.value_counts('pre').reindex(ids).fillna(0).values
+        counts['post'] = post.value_counts('post').reindex(ids).fillna(0).values
+        counts.set_index('id', inplace=True)
+    else:
+        pre_grp = pre.groupby(['pre', 'neuropil']).size()
+        pre_grp = pre_grp[pre_grp > 0]
+        pre_grp.index.set_names(['id', 'neuropil'], inplace=True)
+
+        post_grp = post.groupby(['post', 'neuropil']).size()
+        post_grp = post_grp[post_grp > 0]
+        post_grp.index.set_names(['id', 'neuropil'], inplace=True)
+
+        neuropils = np.unique(np.append(pre_grp.index.get_level_values(1),
+                                        post_grp.index.get_level_values(1)))
+
+        index = pd.MultiIndex.from_product([ids, neuropils],
+                                           names=['id', 'neuropil'])
+
+        counts = pd.concat([pre_grp.reindex(index).fillna(0),
+                            post_grp.reindex(index).fillna(0)],
+                           axis=1)
+        counts.columns = ['pre', 'post']
+        counts = counts[counts.max(axis=1) > 0]
+
+    return counts
 
 
 def predict_transmitter(x, single_pred=False, weighted=True, live_query=True,
-                        dataset='production'):
+                        neuropils=None, batch_size=10, dataset='production', **kwargs):
     """Fetch neurotransmitter predictions for neurons.
 
     Based on Eckstein et al. (2020). Uses a service on spine.janelia.org hosted
@@ -71,7 +133,7 @@ def predict_transmitter(x, single_pred=False, weighted=True, live_query=True,
     Parameters
     ----------
     x :             int | list of int | Neuron/List
-                    Either a flywire segment ID (i.e. root ID), a list thereof or
+                    Either a FlyWire segment ID (i.e. root ID), a list thereof or
                     a Neuron/List. For neurons, the ``.id`` is assumed to be the
                     root ID. If you have a neuron (in FlyWire space) but don't
                     know its ID, use :func:`fafbseg.flywire.neuron_to_segments`
@@ -86,10 +148,23 @@ def predict_transmitter(x, single_pred=False, weighted=True, live_query=True,
                     Whether to query against the live data or against the latest
                     materialized table. The latter is useful if you are working
                     with IDs that you got from another annotation table.
+    neuropils :     str | list of str, optional
+                    Provide neuropil (e.g. ``'AL_R'``) or list thereof (e.g.
+                    ``['AL_R', 'AL_L']``) to filter predictions to these ROIs.
+                    Prefix neuropil with a tilde (e.g. ``~AL_R``) to exclude it.
+    batch_size :    int
+                    Number of IDs to query per batch. Too large batches might
+                    lead to truncated tables: currently individual queries can
+                    not return more than 200_000 rows and you will see a warning
+                    if that limit is exceeded.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query::
+                    Against which FlyWire dataset to query::
                         - "production" (current production dataset, fly_v31)
                         - "sandbox" (i.e. fly_v26)
+    **kwargs
+                    Keyword arguments are passed through to
+                    :func:`fafbseg.flywire.fetch_synapses`.
+
 
     Returns
     -------
@@ -104,16 +179,32 @@ def predict_transmitter(x, single_pred=False, weighted=True, live_query=True,
     """
     # First get the synapses
     syn = fetch_synapses(x, pre=True, post=False, attach=False, min_score=None,
-                         transmitters=True, live_query=live_query)
+                         transmitters=True, live_query=live_query,
+                         neuropils=neuropils is not None,
+                         batch_size=batch_size,
+                         dataset=dataset, **kwargs)
 
-    # Get the predictions
+    if not isinstance(neuropils, type(None)):
+        neuropils = navis.utils.make_iterable(neuropils)
+        filter_in = [n for n in neuropils if not n.startswith('~')]
+        filter_out = [n[1:] for n in neuropils if n.startswith('~')]
+
+        if filter_in:
+            syn = syn[syn.neuropil.isin(filter_in)]
+        if filter_out:
+            syn = syn[~syn.neuropil.isin(filter_out)]
+
+        # Avoid setting-on-copy warning
+        syn = syn.copy()
+
+    # Process the predictions
     return collapse_nt_predictions(syn, single_pred=single_pred,
                                    weighted=weighted, id_col='pre')
 
 
 def fetch_synapses(x, pre=True, post=True, attach=True, min_score=30, clean=True,
                    transmitters=False, neuropils=False, live_query=True,
-                   batch_size=100, dataset='production', progress=True):
+                   batch_size=30, dataset='production', progress=True):
     """Fetch Buhmann et al. (2019) synapses for given neuron(s).
 
     Parameters
@@ -146,16 +237,17 @@ def fetch_synapses(x, pre=True, post=True, attach=True, min_score=30, clean=True
                     compared with the raw synapse information. Currently, we::
                         - drop autapses
                         - drop synapses from/to background (id 0)
-
     batch_size :    int
                     Number of IDs to query per batch. Too large batches might
-                    lead to truncated tables.
+                    lead to truncated tables: currently individual queries can
+                    not return more than 200_000 rows and you will see a warning
+                    if that limit is exceeded.
     live_query :    bool
                     Whether to query against the live data or against the latest
                     materialized table. The latter is useful if you are working
                     with IDs that you got from another annotation table.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query::
+                    Against which FlyWire dataset to query::
                         - "production" (current production dataset, fly_v31)
                         - "sandbox" (i.e. fly_v26)
 
@@ -304,7 +396,7 @@ def fetch_synapses(x, pre=True, post=True, attach=True, min_score=30, clean=True
 
 
 def fetch_adjacency(sources, targets=None, min_score=30, live_query=True,
-                    neuropils=None, batch_size=100, dataset='production',
+                    neuropils=None, batch_size=30, dataset='production',
                     progress=True):
     """Fetch adjacency matrix.
 
@@ -317,7 +409,7 @@ def fetch_adjacency(sources, targets=None, min_score=30, live_query=True,
                     don't know its ID, use :func:`fafbseg.flywire.neuron_to_segments`
                     first.
     targets :       int | list of int | Neuron/List, optional
-                    Either flywire segment ID (i.e. root ID), a list thereof
+                    Either FlyWire segment ID (i.e. root ID), a list thereof
                     or a Neuron/List. For neurons, the ``.id`` is assumed to be
                     the root ID. If you have a neuron (in FlyWire space) but
                     don't know its ID, use :func:`fafbseg.flywire.neuron_to_segments`
@@ -328,15 +420,18 @@ def fetch_adjacency(sources, targets=None, min_score=30, live_query=True,
     neuropils :     str | list of str, optional
                     Provide neuropil (e.g. ``'AL_R'``) or list thereof (e.g.
                     ``['AL_R', 'AL_L']``) to filter connectivity to these ROIs.
+                    Prefix neuropil with a tilde (e.g. ``~AL_R``) to exclude it.
     batch_size :    int
                     Number of IDs to query per batch. Too large batches might
-                    lead to truncated tables.
+                    lead to truncated tables: currently individual queries can
+                    not return more than 200_000 rows and you will see a warning
+                    if that limit is exceeded.
     live_query :    bool
                     Whether to query against the live data or against the latest
                     materialized table. The latter is useful if you are working
                     with IDs that you got from another annotation table.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query::
+                    Against which FlyWire dataset to query::
                         - "production" (current production dataset, fly_v31)
                         - "sandbox" (i.e. fly_v26)
 
@@ -389,14 +484,26 @@ def fetch_adjacency(sources, targets=None, min_score=30, live_query=True,
     # Combine results from batches
     syn = pd.concat(syn, axis=0, ignore_index=True)
 
+    # Depending on how queries were batched, we need to drop duplicate synapses
+    syn.drop_duplicates('id', inplace=True)
+
     # Subset to the desired neuropils
     if not isinstance(neuropils, type(None)):
         neuropils = navis.utils.make_iterable(neuropils)
 
         if len(neuropils):
+            filter_in = [n for n in neuropils if not n.startswith('~')]
+            filter_out = [n[1:] for n in neuropils if n.startswith('~')]
+
             syn['neuropil'] = get_synapse_areas(syn['id'].values)
             syn['neuropil'] = syn.neuropil.astype('category')
-            syn = syn[syn.neuropil.isin(neuropils)].copy()
+
+            if filter_in:
+                syn = syn[syn.neuropil.isin(filter_in)]
+            if filter_out:
+                syn = syn[~syn.neuropil.isin(filter_out)]
+
+            syn = syn.copy()
 
     # Rename some of those columns
     syn.rename({'post_pt_root_id': 'post', 'pre_pt_root_id': 'pre'},
@@ -422,18 +529,17 @@ def fetch_adjacency(sources, targets=None, min_score=30, live_query=True,
 
 def fetch_connectivity(x, clean=True, style='simple', min_score=30,
                        upstream=True, downstream=True, transmitters=False,
-                       neuropils=None, batch_size=100, live_query=True,
+                       neuropils=None, batch_size=30, live_query=True,
                        dataset='production', progress=True):
     """Fetch Buhmann et al. (2019) connectivity for given neuron(s).
 
     Parameters
     ----------
     x :             int | list of int | Neuron/List
-                    Either a flywire segment ID (i.e. root ID), a list thereof
-                    or a Neuron/List. For neurons, the ``.id`` is assumed to be
-                    the root ID. If you have a neuron (in FlyWire space) but
-                    don't know its ID, use :func:`fafbseg.flywire.neuron_to_segments`
-                    first.
+                    Either a FlyWire root ID, a list thereof or a Neuron/List.
+                    For neurons, the ``.id`` is assumed to be the root ID. If
+                    you have a neuron (in FlyWire space) but don't know its ID,
+                    use :func:`fafbseg.flywire.neuron_to_segments` first.
     clean :         bool
                     If True, we will perform some clean up of the connectivity
                     compared with the raw synapse information. Currently, we::
@@ -462,15 +568,18 @@ def fetch_connectivity(x, clean=True, style='simple', min_score=30,
     neuropils :     str | list of str, optional
                     Provide neuropil (e.g. ``'AL_R'``) or list thereof (e.g.
                     ``['AL_R', 'AL_L']``) to filter connectivity to these ROIs.
+                    Prefix neuropil with a tilde (e.g. ``~AL_R``) to exclude it.
     batch_size :    int
                     Number of IDs to query per batch. Too large batches might
-                    lead to truncated tables.
+                    lead to truncated tables: currently individual queries can
+                    not return more than 200_000 rows and you will see a warning
+                    if that limit is exceeded.
     live_query :    bool
                     Whether to query against the live data or against the latest
                     materialized table. The latter is useful if you are working
                     with IDs that you got from another annotation table.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query::
+                    Against which FlyWire dataset to query::
                         - "production" (current production dataset, fly_v31)
                         - "sandbox" (i.e. fly_v26)
 
@@ -532,9 +641,18 @@ def fetch_connectivity(x, clean=True, style='simple', min_score=30,
         neuropils = navis.utils.make_iterable(neuropils)
 
         if len(neuropils):
+            filter_in = [n for n in neuropils if not n.startswith('~')]
+            filter_out = [n[1:] for n in neuropils if n.startswith('~')]
+
             syn['neuropil'] = get_synapse_areas(syn['id'].values)
             syn['neuropil'] = syn.neuropil.astype('category')
-            syn = syn[syn.neuropil.isin(neuropils)].copy()
+
+            if filter_in:
+                syn = syn[syn.neuropil.isin(filter_in)]
+            if filter_out:
+                syn = syn[~syn.neuropil.isin(filter_out)]
+
+            syn = syn.copy()
 
     # Rename some of those columns
     syn.rename({'post_pt_root_id': 'post', 'pre_pt_root_id': 'pre'},
